//                     version.cc

#include "main.ih"

#include "VERSION"

namespace Icmbuild
{
    char version[]  = VERSION;
    char year[]     = YEARS;

    char author[] = "Frank B. Brokken (f.b.brokken@rug.nl)";
}
